# mkTextBind w
#
# Create a top-level window that illustrates how you can bind
# Tcl commands to regions of text in a text widget.
#
# Arguments:
#    w -	Name to use for new top-level window.

proc mkTextBind {{w .bindings}} {
    catch {destroy $w}
    toplevel $w
    dpos $w
    wm title $w "Text Demonstration - Tag Bindings"
    wm iconname $w "Text Bindings"
    button $w.ok -text  -command "destroy $w"
    text $w.t -relief raised -bd 2 -yscrollcommand "$w.s set" -setgrid true \
	    -width 60 -height 28 \
	    -font "-Adobe-Helvetica-Medium-R-Normal-*-120-*"
    scrollbar $w.s -relief flat -command "$w.t yview"
    pack append $w $w.ok {bottom fillx} $w.s {right filly} $w.t {expand fill}

    # Set up display styles

    if {[tk colormodel $w] == "color"} {
	set bold "-foreground red"
	set normal "-foreground {}"
    } else {
	set bold "-foreground white -background black"
	set normal "-foreground {} -background {}"
    }
    $w.t insert 0.0 {\
eLXg widget ̕\X^C𐧌䂷̂Ɠ^O
JjYgāAeLXg Tcl ̃R}h蓖Ă
Ƃł܂BɂA}EXL[{[h̃ANV
 Tcl ̃R}hs悤ɂȂ܂BႦ΁A
̃LoX̃fvOɂĂ̐ɂ͂̂悤
^OĂ܂B}EX̏ɎĂƐ
A{^3 Ƃ̐̃fn܂܂B

̃fpbP[Wɂ́ATk ̃LoX widget ɂĂ
f߂Ă܂B̂̃f
ĊȒPɐ܂B

}
    insertWithTags $w.t \
{1. LoX widget ɍ邱Ƃ̂łACe̎ޑSĂ
ւTvB} d1
    insertWithTags $w.t \n\n
    insertWithTags $w.t \
{2. ȒP 2̃vbgBf[^\_𓮂Ƃ
łB} d2
    insertWithTags $w.t \n\n
    insertWithTags $w.t \
{3. eLXgACẽAJ[ƍsB} d3
    insertWithTags $w.t \n\n
    insertWithTags $w.t \
{4. CACê߂̖̓̌`̃GfB^B} d4
    insertWithTags $w.t \n\n
    insertWithTags $w.t \
{5. ^uXgbvύX邽߂̋@\̃[[B} d5
    insertWithTags $w.t \n\n
    insertWithTags $w.t \
{6. LoXǂăXN[̂ObhB} d6

    foreach tag {d1 d2 d3 d4 d5 d6} {
	$w.t tag bind $tag <Any-Enter> "$w.t tag configure $tag $bold"
	$w.t tag bind $tag <Any-Leave> "$w.t tag configure $tag $normal"
    }
    $w.t tag bind d1 <3> mkItems
    $w.t tag bind d2 <3> mkPlot
    $w.t tag bind d3 <3> mkCanvText
    $w.t tag bind d4 <3> mkArrow
    $w.t tag bind d5 <3> mkRuler
    $w.t tag bind d6 <3> mkScroll

    $w.t mark set insert 0.0
    bind $w <Any-Enter> "focus $w.t"
}

# The procedure below inserts text into a given text widget and
# applies one or more tags to that text.  The arguments are:
#
# w		Window in which to insert
# text		Text to insert (it's inserted at the "insert" mark)
# args		One or more tags to apply to text.  If this is empty
#		then all tags are removed from the text.

proc insertWithTags {w text args} {
    set start [$w index insert]
    $w insert insert $text
    foreach tag [$w tag names $start] {
	$w tag remove $tag $start insert
    }
    foreach i $args {
	$w tag add $i $start insert
    }
}
