'\"
'\" Copyright (c) 1993  Software Research Associates, Inc.
'\" Permission to use, copy, modify, and distribute this software and its
'\" documentation for any purpose and without fee is hereby granted, provided
'\" that the above copyright notice appear in all copies and that both that
'\" copyright notice and this permission notice appear in supporting
'\" documentation, and that the name of Software Research Associates not be
'\" used in advertising or publicity pertaining to distribution of the
'\" software without specific, written prior permission.  Software Research
'\" Associates makes no representations about the suitability of this software
'\" for any purpose.  It is provided "as is" without express or implied
'\" warranty.
'\" 
'\" $Id: TkJP.man,v 1.1 1993/11/15 06:50:13 nisinaka Exp $
'
.so man.macros
.de UL
\\$1\l'|0\(ul'\\$2
..
.HS TkJP tk
.if n .na
.BS
.SH NAME
TkJapanization \- overview of Tk Japanization
.BE

.SH INTRODUCTION
This document provides an overview of the Japanization of Tk.
The Japanization includes the following features:
.RS
.nf

* Modification of widgets to handle kanji strings.
* PostScript output of kanji strings for canvas widgets.

.fi
.RE
There are two main policies for the Japanization:
"Users do not have to worry about details like kanji code"
and
"Any scripts for the original Tk are executable".
'
.SH "DISPLAY KANJI STRINGS"
The following widgets can display kanji strings:
.RS
.nf

button, checkbutton, menubutton, radiobutton
canvas (text item)
entry, text
label
listbox
menu
message
scale
.fi
.RE
.PP
These widgets have an additional resource and option for kanji fonts.
The resource name is \fBkanjiFont\fP,
the resource class name is \fBkanjiFont\fP,
and the option is \fB-kanjifont\fP.
.PP
The default ascii font and kanji font of these widgets are
\fBa14\fP and \fBk14\fP respectively.
These default fonts are defined in the file "default.h".
If you want to change them,
you need to modify the file and recompile Tk.
'
.SH "KANJI INPUT"
This modification allows you to input kanji strings
by calling a kanji input server.
The only input server that the current implementation supports
is \fBkinput2\fP.
Instead of embedding the functions for kanji input into each widget,
we provided the \fBkanjiInput\fP command.
.TP 4
\fBkanjiInput \fIoption\fR ?\fIarg ...\fR?
Perform one of several kanji input operations,
depending on \fIoption\fR.
The legal \fIoption\fRs are:
.RS
.TP 4
\fBkanjiInput start \fIclientWindow\fR ?\fIattributes ...\fR?
Send a request for kanji input to the kanji input server.
The \fIclientWindow\fR is the widget path name
where you want to do the kanji input.
The \fIattributes\fP are the parameters to pass for the initialization
when you invoke the input server.
The \fIattributes\fP are dependent upon the input server.
For kinput2, the legal \fIattributes\fP are:
.RS
.TP 4
\fB\-variable\fP \fIvariable-name\fP
The \fIvariable-name\fP is the name of the global variable
to which you want to assign the result of kanji input.
You can trace this variable and call specific procedures
to deal with the kanji string received from the input server.
.br
Every input server should have this attribute.
.TP 4
\fB\-inputStyle\fP \fIstyle\fP
The \fIstyle\fP argument indicates the input style.
It may have any of the values: \fBroot\fP, \fBoff\fP, \fBover\fP
which mean "root window style input",
"off-the-spot style input",
"over-the-spot style input"
respectively.
.TP 4
\fB\-foreground\fP \fIcolor\fP
Specifies the foreground color of the kanji input area.
For kinput2, this attribute is effective
only when you choose the "over-the-spot style input".
.TP 4
\fB\-background\fP \fIcolor\fP
Specifies the background color of the kanji input area.
For kinput2, this attribute is effective
only when you choose the "over-the-spot style input".
.TP 4
\fB\-clientArea\fP \fIarea\fP
Specifies the area for kanji input.
\fIarea\fP is a list of four elements:
.br
\ \ {x\ \ y\ \ width\ \ height}
.br
Coordinates are relative to the \fIclientWindow\fR.
.TP 4
\fB\-statusArea\fP \fIarea\fP
Specifies the area for showing the status of kanji input.
The \fIarea\fP is specified in the same way as for \fB-clientArea\fP.
.TP 4
\fB\-focusWindow\fP \fIwindow\fP
Specifies the window where you want to do the kanji input.
The \fIwindow\fP should be the \fIclientWindow\fP or its subwindow.
The default window is the \fIclientWindow\fP.
.TP 4
\fB\-fonts\fP \fIfont-list\fP
Specifies the list of font names to use for kanji input.
Usually you need to specify both ascii font and kanji font.
The order of the list elements have no meaning.
.TP 4
\fB\-lineSpacing\fP \fIspacing\fP
Specifies the height of a line on kanji input area.
The value of \fIspacing\fP is the number of dots.
.TP 4
\fB\-spot\fP \fIspot\fP
Specifies the XY-coordinates of the spot location of the conversion.
\fISpot\fP is a list of the following form:
.br
\ \ {X-coordinate\ \ Y-coordinate}
.br
It is the same format as the return value of the \fBxypos\fP
widget command of Text and Entry widgets.
These coordinates are relative to the coordinates of
the \fIclientWindow\fR.
.TP 4
\fB\-cursor\fP \fIcursor\fP
Specifies the shape of the cursor.
The value of \fIcursor\fP is same as for \fBTk_GetCursor()\fP.
.TP 4
\fB\-eventCaptureMethod\fP \fImethod\fP
Specifies the style to capture events from input server.
It may have any of the values:
\fBnone\fP, \fBinputOnly\fP, and \fBfocusSelect\fP.
The default value is \fBinputOnly\fP.
Actually the current implementation of kinput2 only supports \fBinputOnly\fP.
.RE
.TP 4
\fBkanjiInput attribute \fIclientWindow\fR ?\fIattributes ...\fR?
.TP 4
\fBkanjiInput attribute \fIclientWindow\fR ?\fIattribute-name\fR?
These two return or change the current attributes of the kanji input server.
In the first form, \fIattributes\fP are passed to the kanji input server,
just as for \fBkanjiInput start\fP.
In this case, the value of the specifed attributes will be changed.
.br
In the second form, \fIattribute-name\fR is a name of an attribute.
For example, the attribute name for input style is "\fB\-inputStyle\fP".
In this case, the command returns the current value of the attribute.
If no attribute name is specifed,
then returns a list of all attribute names and values.
.TP 4
\fBkanjiInput end \fIclientWindow\fR
Terminate the current kanji input.
.RE
.PP
Not all of these attributes are always effective.
For example, if the input style is \fBroot\fP,
then the specifications of fonts or colors are meaningless.
.PP
For over-the-spot style input,
Text and Entry widgets now have a new command \fBxypos\fP.
.TP 4
\fIpassName\fP \fBxypos\fP \fIindex\fP
Returns the coordinates of the position specified by \fIindex\fP
in a form of a list \fI{x y}\fP.
If the specified position is out of the window,
then returns a null list.
.PP
Initial bindings for Text and Entry widgets are given by the file "kinput.tcl"
which is loaded for the initialization of \fBwish\fP.
The default input style is "over-the-spot" for Text widgets
and "root" for Entry widgets.
The default key bindings to start kanji input are
<Control-kanji>, <Control-backslash> and <Control-Shift_R>.
If you want to change these defaults,
please look at the file "kinput.tcl" and modify it.
'
.SH "CUT&PASTE KANJI STRINGS"
Selection is extended to be able to handle COMPOUND_TEXT
and you can cut & paste kanji strings.
.PP
Text, Entry, Listbox and Canvas (text item) now accept
\fBTEXT\fP and \fBCOMPOUND_TEXT\fP as for a selection target.
If \fBTEXT\fP or \fBCOMPOUND_TEXT\fP is specified,
you can cut & paste kanji strings.
If \fBSTRING\fP is specified,
all you can get is ascii strings.
.PP
The \fBselection\fP command is modified as follows:
.TP 4
\fBselection get\fR ?\fItype\fR?
The \fItype\fR defaults to \fBSTRING\fP in the original Tk.
To handle kanji strings, we modified the default to \fBCOMPOUND_TEXT\fP.
When the selection target is \fBCOMPOUND_TEXT\fP,
\fBselection get\fP command converts the string
from \fBCOMPOUND_TEXT\fP to internal code.
Thus the command returns the strings encoded with internal code.
.TP 4
\fBselection handle\fR \fIwindow\fR \fIcommand\fP ?\fItype\fR? ?\fIformat\fR?
The default of \fItype\fR and \fIformat\fR is now \fBCOMPOUND_TEXT\fP.
When the \fIformat\fR is either \fBCOMPOUND_TEXT\fP or \fBTEXT\fP,
\fIcommand\fP converts the string from internal code to \fBCOMPOUND_TEXT\fP.
'
.SH "POSTSCRIPT OUTPUT FROM CANVAS WIDGET"
The modification includes the PostScript generation of
text items on canvas widgets.
The original Tk generates a PostScript font name
from a family name of the X font,
but unfortunately there is no kanji PostScript font name
corresponding to the X kanji fonts.
So the current implementation always uses \fBRyumin-Light-H\fP
for any kanji fonts.
This is defined in the file "default.h".
If you want to change it,
you need to modify the file and recompile Tk.
'
.SH "COEXISTING WITH THE ORIGINAL TCL/TK"
Some of the library files (usually installed in "/usr/local/lib/tk")
are modified for the Japanization.
Since these modifications do not affect anything about
the behavior of the original Tcl/Tk,
the original version can work with the libraries of this Japanized Tcl/Tk.
'
.SH PROBLEMS
The Japanization does not use the internationalization features of X11R5 at all.
So the kinput2 (which does not depend on the XIM)
is the only Japanese text input method with the current implementation.
'
.SH AUTHORS
The original Tcl/Tk was developped by
Dr. John Ousterhout (ouster@sprite.berkeley.edu)
from University of California at Berkeley.
This Japanization is mainly done by Yoshiyuki Nishinaka (nisinaka@sra.co.jp)
from Software Research Associates, Inc. with the supports of
Hiroshi Sako (sakoh@sra.co.jp) and Makoto Ishisone (ishisone@sra.co.jp).
